pilas.depurador.DepuradorDeshabilitado

Package pilas :: Module depurador :: Class DepuradorDeshabilitado |
[hide private]
[frames] | no frames]

# Class DepuradorDeshabilitado

source code

    object --+
             |
            DepuradorDeshabilitado

Known Subclasses:
  - Depurador

Instance Methods | [hide private]
comienza_dibujado(self, motor, painter) | source code
dibuja_al_actor(self, motor, painter, actor) | source code
termina_dibujado(self, motor, painter) | source code
cuando_pulsa_tecla(self, codigo_tecla, texto_tecla) | source code
cuando_mueve_el_mouse(self, x, y) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`